import React from "react";
import { unstable_trace as trace } from "scheduler/tracing";
import { beautifyKey } from "@ui-schema/ui-schema";
import { ValidityHelperText } from "../Component/LocaleHelperText";

const StringRenderer = ({
  ownKey,
  schema,
  value,
  multiline,
  onChange,
  storeKeys,
  showValidity,
  required,
  errors
}) => {
  let Renderer = 'input';

  if (multiline) {
    Renderer = 'textarea';
  }

  let classFormControl = ["form-control"];

  if (showValidity && errors.size) {
    classFormControl.push('is-invalid');
  }

  return React.createElement("div", {
    className: "form-group",
    noValidate: true
  }, React.createElement("label", {
    htmlFor: ownKey
  }, beautifyKey(ownKey)), React.createElement(Renderer, {
    className: classFormControl.join(' '),
    required: required,
    value: value || '',
    onChange: e => trace("textfield onchange", performance.now(), () => {
      const value = e.target.value;
      onChange(store => store.setIn(storeKeys, value));
    })
  }), React.createElement(ValidityHelperText, {
    errors: errors,
    showValidity: showValidity,
    schema: schema
  }));
};

export { StringRenderer };